==> mule-profiling-api-1.1.0-20220125-sources.jar: org/mule/runtime/api/profiling/type/RuntimeProfilingEventTypes.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.api.profiling.type;

import org.mule.api.annotation.Experimental;
import org.mule.runtime.api.profiling.type.context.ComponentThreadingProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.ExtensionProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.ComponentProcessingStrategyProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.TaskSchedulingProfilingEventContext;

/**
 * {@link ProfilingEventType}'s associated to the Runtime {@link ProfilingEventType}'s.
 *
 * @since 1.0
 */
@Experimental
public final class RuntimeProfilingEventTypes {

  private static final String MULE_NAMESPACE = "MULE";

  /**
   * A {@link ProfilingEventType} that indicates that a runtime event has reached the processing strategy that orchestrates an
   * operation's execution. The processing strategy is scheduling the execution of the operation, which may involve a thread
   * switch.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_SCHEDULING_OPERATION_EXECUTION =
      ProcessingStrategyProfilingEventType.of("PS_SCHEDULING_OPERATION_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation is about to begin its execution. This boundary is expressed as
   * broadly as possible, and will include, for instance, the execution of the interceptors defined for the operation. It's
   * triggered from the processing strategy.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_STARTING_OPERATION_EXECUTION =
      ProcessingStrategyProfilingEventType.of("PS_STARTING_OPERATION_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation has finished its execution, and the processing strategy must
   * resolve the message passing of the resultant runtime event to the flow which may involve a thread switch. It's triggered from
   * the processing strategy.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_OPERATION_EXECUTED =
      ProcessingStrategyProfilingEventType.of("PS_OPERATION_EXECUTED", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the processing strategy has executed the message passing and is handling the
   * control back to the flow.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_FLOW_MESSAGE_PASSING =
      ProcessingStrategyProfilingEventType.of("PS_FLOW_MESSAGE_PASSING", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that a runtime event reached the processing strategy that orchestrates a flow's
   * execution. The processing strategy is scheduling the execution of the flow, which may involve a thread switch.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_SCHEDULING_FLOW_EXECUTION =
      ProcessingStrategyProfilingEventType.of("PS_SCHEDULING_FLOW_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the flow is about to begin its execution.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> STARTING_FLOW_EXECUTION =
      ProcessingStrategyProfilingEventType.of("STARTING_FLOW_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the flow has finished its execution.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> FLOW_EXECUTED =
      ProcessingStrategyProfilingEventType.of("FLOW_EXECUTED", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an extension-specific profiling event has happened.
   */
  public static final ProfilingEventType<ExtensionProfilingEventContext> EXTENSION_PROFILING_EVENT =
      new ExtensionProfilingEventType("EXTENSION_PROFILING_EVENT", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation is about to begin its execution. Unlike
   * {@link #PS_STARTING_OPERATION_EXECUTION}, it's triggered from the component itself.
   */
  public static final ProfilingEventType<ComponentThreadingProfilingEventContext> STARTING_OPERATION_EXECUTION =
      ComponentThreadingProfilingEventType.of("STARTING_OPERATION_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation has finished its execution. Unlike
   * {@link #PS_OPERATION_EXECUTED}, it's triggered from the component itself.
   */
  public static final ProfilingEventType<ComponentThreadingProfilingEventContext> OPERATION_EXECUTED =
      ComponentThreadingProfilingEventType.of("OPERATION_EXECUTED", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation will no longer use the thread where it started. This does not
   * mean that the component has finished its execution, because it can be non-blocking. To see the completion refer to
   * {@link #OPERATION_EXECUTED}.
   */
  public static final ProfilingEventType<ComponentThreadingProfilingEventContext> OPERATION_THREAD_RELEASE =
      ComponentThreadingProfilingEventType.of("OPERATION_THREAD_RELEASE", MULE_NAMESPACE);

  public static final ProfilingEventType<TaskSchedulingProfilingEventContext> SCHEDULING_TASK_EXECUTION =
      new TaskSchedulingProfilingEventType("SCHEDULING_TASK_EXECUTION", MULE_NAMESPACE);

  public static final ProfilingEventType<TaskSchedulingProfilingEventContext> STARTING_TASK_EXECUTION =
      new TaskSchedulingProfilingEventType("STARTING_TASK_EXECUTION", MULE_NAMESPACE);

  public static final ProfilingEventType<TaskSchedulingProfilingEventContext> TASK_EXECUTED =
      new TaskSchedulingProfilingEventType("TASK_EXECUTED", MULE_NAMESPACE);

  private RuntimeProfilingEventTypes() {}

}

==> mule-profiling-api-1.1.0-20220523-sources.jar: org/mule/runtime/api/profiling/type/RuntimeProfilingEventTypes.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.api.profiling.type;

import org.mule.api.annotation.Experimental;
import org.mule.runtime.api.profiling.type.context.ByteBufferProviderEventContext;
import org.mule.runtime.api.profiling.type.context.ComponentThreadingProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.ExtensionProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.ComponentProcessingStrategyProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.SpanProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.TaskSchedulingProfilingEventContext;
import org.mule.runtime.api.profiling.type.context.TransactionProfilingEventContext;

/**
 * {@link ProfilingEventType}'s associated to the Runtime {@link ProfilingEventType}'s.
 *
 * @since 1.0
 */
@Experimental
public final class RuntimeProfilingEventTypes {

  private static final String MULE_NAMESPACE = "MULE";

  /**
   * A {@link ProfilingEventType} that indicates that a runtime event has reached the processing strategy that orchestrates an
   * operation's execution. The processing strategy is scheduling the execution of the operation, which may involve a thread
   * switch.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_SCHEDULING_OPERATION_EXECUTION =
      ProcessingStrategyProfilingEventType.of("PS_SCHEDULING_OPERATION_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation is about to begin its execution. This boundary is expressed as
   * broadly as possible, and will include, for instance, the execution of the interceptors defined for the operation. It's
   * triggered from the processing strategy.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_STARTING_OPERATION_EXECUTION =
      ProcessingStrategyProfilingEventType.of("PS_STARTING_OPERATION_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation has finished its execution, and the processing strategy must
   * resolve the message passing of the resultant runtime event to the flow which may involve a thread switch. It's triggered from
   * the processing strategy.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_OPERATION_EXECUTED =
      ProcessingStrategyProfilingEventType.of("PS_OPERATION_EXECUTED", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the processing strategy has executed the message passing and is handling the
   * control back to the flow.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_FLOW_MESSAGE_PASSING =
      ProcessingStrategyProfilingEventType.of("PS_FLOW_MESSAGE_PASSING", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that a runtime event reached the processing strategy that orchestrates a flow's
   * execution. The processing strategy is scheduling the execution of the flow, which may involve a thread switch.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> PS_SCHEDULING_FLOW_EXECUTION =
      ProcessingStrategyProfilingEventType.of("PS_SCHEDULING_FLOW_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the flow is about to begin its execution.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> STARTING_FLOW_EXECUTION =
      ProcessingStrategyProfilingEventType.of("STARTING_FLOW_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the flow has finished its execution.
   */
  public static final ProfilingEventType<ComponentProcessingStrategyProfilingEventContext> FLOW_EXECUTED =
      ProcessingStrategyProfilingEventType.of("FLOW_EXECUTED", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an extension-specific profiling event has happened.
   */
  public static final ProfilingEventType<ExtensionProfilingEventContext> EXTENSION_PROFILING_EVENT =
      new ExtensionProfilingEventType("EXTENSION_PROFILING_EVENT", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation is about to begin its execution. Unlike
   * {@link #PS_STARTING_OPERATION_EXECUTION}, it's triggered from the component itself.
   */
  public static final ProfilingEventType<ComponentThreadingProfilingEventContext> STARTING_OPERATION_EXECUTION =
      ComponentThreadingProfilingEventType.of("STARTING_OPERATION_EXECUTION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation has finished its execution. Unlike
   * {@link #PS_OPERATION_EXECUTED}, it's triggered from the component itself.
   */
  public static final ProfilingEventType<ComponentThreadingProfilingEventContext> OPERATION_EXECUTED =
      ComponentThreadingProfilingEventType.of("OPERATION_EXECUTED", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an operation will no longer use the thread where it started. This does not
   * mean that the component has finished its execution, because it can be non-blocking. To see the completion refer to
   * {@link #OPERATION_EXECUTED}.
   */
  public static final ProfilingEventType<ComponentThreadingProfilingEventContext> OPERATION_THREAD_RELEASE =
      ComponentThreadingProfilingEventType.of("OPERATION_THREAD_RELEASE", MULE_NAMESPACE);

  public static final ProfilingEventType<TaskSchedulingProfilingEventContext> SCHEDULING_TASK_EXECUTION =
      new TaskSchedulingProfilingEventType("SCHEDULING_TASK_EXECUTION", MULE_NAMESPACE);

  public static final ProfilingEventType<TaskSchedulingProfilingEventContext> STARTING_TASK_EXECUTION =
      new TaskSchedulingProfilingEventType("STARTING_TASK_EXECUTION", MULE_NAMESPACE);

  public static final ProfilingEventType<TaskSchedulingProfilingEventContext> TASK_EXECUTED =
      new TaskSchedulingProfilingEventType("TASK_EXECUTED", MULE_NAMESPACE);

  public static final ProfilingEventType<ByteBufferProviderEventContext> MEMORY_BYTE_BUFFER_ALLOCATION =
      new ByteBufferAllocationEventType("MEMORY_BYTE_BUFFER_ALLOCATION", MULE_NAMESPACE);

  public static final ProfilingEventType<ByteBufferProviderEventContext> MEMORY_BYTE_BUFFER_DEALLOCATION =
      new ByteBufferAllocationEventType("MEMORY_BYTE_BUFFER_DEALLOCATION", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that a transaction is being started. To see the completion refer to
   * {@link #TX_COMMIT} or {@link #TX_ROLLBACK}.
   */
  public static final ProfilingEventType<TransactionProfilingEventContext> TX_START =
      new TransactionProfilingEventType("TX_START", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that an already started transaction has passed by a component that could have
   * changed its state (beginning a transaction, commiting or rollling back) but it didn't, given the current configuration (e.g.
   * not being the error handler that has to roll back the transaction).
   */
  public static final ProfilingEventType<TransactionProfilingEventContext> TX_CONTINUE =
      new TransactionProfilingEventType("TX_CONTINUE", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the transaction is being committed.
   */
  public static final ProfilingEventType<TransactionProfilingEventContext> TX_COMMIT =
      new TransactionProfilingEventType("TX_COMMIT", MULE_NAMESPACE);

  /**
   * A {@link ProfilingEventType} that indicates that the transaction is being rolled back.
   */
  public static final ProfilingEventType<TransactionProfilingEventContext> TX_ROLLBACK =
      new TransactionProfilingEventType("TX_ROLLBACK", MULE_NAMESPACE);
  public static final ProfilingEventType<SpanProfilingEventContext> START_SPAN =
      new SpanStartProfilingEventType("START_SPAN", MULE_NAMESPACE);
  public static final ProfilingEventType<SpanProfilingEventContext> END_SPAN =
      new SpanEndProfilingEventType("END_SPAN", MULE_NAMESPACE);

  private RuntimeProfilingEventTypes() {}

}
